Index: src/interpreter/interpreter.h |
diff --git a/src/interpreter/interpreter.h b/src/interpreter/interpreter.h |
index 5c2b34048d5e5d6403ca1fa01a11349f359b7fb2..f8d31923943c8087de444bc03f9864e3cf6a2c44 100644 |
--- a/src/interpreter/interpreter.h |
+++ b/src/interpreter/interpreter.h |
@@ -77,8 +77,9 @@ class Interpreter { |
template <class Generator> |
void DoBinaryOp(InterpreterAssembler* assembler); |
- // Generates code to perform the count operations via |callable|. |
- void DoCountOp(Callable callable, InterpreterAssembler* assembler); |
+ // Generates code to perform the count operations via |Generator|. |
+ template <class Generator> |
+ void DoCountOp(InterpreterAssembler* assembler); |
epertoso
2016/05/17 15:21:52
Same here, how about renaming this one to DoUnaryO
rmcilroy
2016/05/17 19:59:17
Done.
|
// Generates code to perform the comparison operation associated with |
// |compare_op|. |